@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # remove tty given as argument from utmp file
 
 import utmp, sys
@@ -8,12 +8,12 @@ a = utmp.UtmpRecord()
 
 line = sys.argv[1]
 
-b = a.getutline_dict(line)
+b = a.getutline(line)
 if not b:
-    print line, "is not occupied, cannot remove."
+    print (line, "is not occupied, cannot remove.")
     sys.exit()
 b.ut_type = DEAD_PROCESS
 b.ut_line = ''
 b.ut_user = ''
-a.pututline_dict(b)
+a.pututline(b)
 
