@@ -8,15 +8,15 @@ class UtmpEntry:
         self.clear()
         if len(arg)==1:
             arg = arg[0]
-        if (type(arg)==types.TupleType or type(arg)==types.ListType) and arg:
+        if (type(arg)==tuple or type(arg)==list) and arg:
             self.ut_type, self.ut_pid, self.ut_line, \
             self.ut_id, self.ut_user, self.ut_host, \
             self.ut_exit, self.ut_session, self.ut_tv, \
             self.ut_addr_v6 = arg
-        elif type(arg)==types.DictType:
+        elif type(arg)==dict:
             for i in arg.keys():
                 self[i] = arg[i]
-        elif type(arg)==types.InstanceType:
+        elif type(arg)==type(self):
             self.ut_type, self.ut_pid, self.ut_line, \
             self.ut_id, self.ut_user, self.ut_host, \
             self.ut_exit, self.ut_session, self.ut_tv, \
@@ -26,7 +26,7 @@ class UtmpEntry:
             arg.ut_addr_v6
         for i in dictarg.keys():
             self[i] = dictarg[i]
-    
+
     def clear(self):
             self.ut_type = EMPTY
             self.ut_pid = 0
@@ -38,7 +38,7 @@ class UtmpEntry:
             self.ut_session = 0
             self.ut_tv = (0, 0)
             self.ut_addr_v6 = (0, 0, 0, 0)
-            
+
     def _as_tuple(self):
         return (self.ut_type, self.ut_pid, self.ut_line, \
             self.ut_id, self.ut_user, self.ut_host, \
@@ -67,8 +67,8 @@ class UtmpEntry:
         elif item=='ut_addr_v6' or item==9:
             return self.ut_addr_v6
         else:
-            raise IndexError, "Bad key used to access UtmpEntry: "+repr(item)
-                    
+            raise IndexError("Bad key used to access UtmpEntry: "+repr(item))
+
     def __setitem__(self, item, val):
         if item=='ut_type' or item==0:
             self.ut_type=val
@@ -91,26 +91,37 @@ class UtmpEntry:
         elif item=='ut_addr_v6' or item==9:
             self.ut_addr_v6=val
         else:
-            raise IndexError, "Bad key used to access UtmpEntry: "+repr(item)
-	    
-		
+            raise IndexError("Bad key used to access UtmpEntry: "+repr(item))
+
+    def __repr__(self):
+        fs = []
+        for key in 'ut_type', 'ut_pid', 'ut_line', \
+                   'ut_id', 'ut_user', 'ut_host', \
+                   'ut_exit', 'ut_session', 'ut_tv', \
+                   'ut_addr_v6':
+            fs.append( key+'='+repr(self[key]) )
+        fs = ', '.join(fs)
+        r = fs
+        r = 'utmp.UtmpEntry( %s )' % fs
+        return r
 
 class UtmpRecord:
 
     def __init__(self, fname=None):
         if fname:
             utmpaccess.utmpname(fname)
+        self.fname = fname
         self.setutent()
-        
+
     def _makeclass(self, a):
         if not a:
             return None
         return UtmpEntry(a)
-        
+
     def setutent(self):
         "rewinds the file pointer to the beginning of the utmp file."
         utmpaccess.setutent()
-        
+
     def endutent(self):
         "closes the utmp file."
         utmpaccess.endutent()
@@ -123,12 +134,14 @@ class UtmpRecord:
     def __iter__(self):
         return self
 
-    def next(self):
+    def __next__(self):
         r = self.getutent()
-	if not r:
-	    raise StopIteration
+        if not r:
+            raise StopIteration
         return r
-                
+
+    next = __next__
+
     def pututline(self, *ut, **dictut):
         """writes the UtmpEntry provided as parameter into the utmp file. It uses getutid() to search
         for the proper place in the file to insert the new entry. If it cannot find an
@@ -138,8 +151,8 @@ class UtmpRecord:
         else:
             u = ut
         u = UtmpEntry(u, **dictut)
-        apply(utmpaccess.pututline, u._as_tuple())
-            
+        utmpaccess.pututline(*u._as_tuple())
+
     def getutid(self, ut_type, ut_id=''):
         """searches forward from the current file position in the utmp
         file based upon ut_type. If ut_type is RUN_LVL,  BOOT_TIME, 
@@ -161,8 +174,11 @@ class UtmpRecord:
     pututline_dict = pututline
     getutid_dict = getutid
     getutline_dict = getutline
-        
+
     def __del__(self):
         self.endutent()
-        
-        
+
+    def __repr__(self):
+        if not self.fname:
+            fname = ''
+        return 'utmp.UtmpRecord(%s)' % fname
